package com.hw.ems.base.service;

import com.hw.common.core.domain.Ztree;
import com.hw.ems.base.domain.BaseMonitorInfo;
import com.hw.ems.base.domain.BaseSubentryType;
import com.hw.ems.base.domain.vo.TreeSelect;

import java.util.List;


/**
 * 分项类型管理Service接口
 *
 * @author YinQ
 * @date 2023-05-06
 */
public interface IBaseSubentryTypeService
{
    /**
     * 查询分项类型管理
     *
     * @param objid 分项类型管理主键
     * @return 分项类型管理
     */
    public BaseSubentryType selectBaseSubentryTypeByObjid(Long objid);

    /**
     * 查询分项类型管理列表
     *
     * @param baseSubentryType 分项类型管理
     * @return 分项类型管理集合
     */
    public List<BaseSubentryType> selectBaseSubentryTypeList(BaseSubentryType baseSubentryType);

    /**
     * 新增分项类型管理
     *
     * @param baseSubentryType 分项类型管理
     * @return 结果
     */
    public int insertBaseSubentryType(BaseSubentryType baseSubentryType);

    /**
     * 修改分项类型管理
     *
     * @param baseSubentryType 分项类型管理
     * @return 结果
     */
    public int updateBaseSubentryType(BaseSubentryType baseSubentryType);

    /**
     * 批量删除分项类型管理
     *
     * @param objids 需要删除的分项类型管理主键集合
     * @return 结果
     */
    public int deleteBaseSubentryTypeByObjids(Long[] objids);

    /**
     * 删除分项类型管理信息
     *
     * @param objid 分项类型管理主键
     * @return 结果
     */
    public int deleteBaseSubentryTypeByObjid(Long objid);

    public List<BaseSubentryType> selectSubentryList(BaseMonitorInfo baseMonitorInfo);
    public List<TreeSelect> buildTreeSelect(List<BaseSubentryType> subentrys);
    public List<BaseSubentryType> buildTree(List<BaseSubentryType> menus);

    List<Ztree> selectBaseSubentryTypeTree();
}
